/*
 * Photo Image Print System
 * Copyright (C) 2002-2005 EPSON AVASYS Corporation.
 * Copyright (C) Seiko Epson Corporation 2002-2008.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON AVASYS Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON AVASYS Public License and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON AVASYS Public License.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __DEBUG_H__
#define __DEBUG_H__

//#if DEBUG  /* DEBUG */

#include <stdarg.h>
#include "pipsdef.h"

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */

#define DEBUG_START debug_init ()
#define DEDBUG_END debug_end ()
#define DEBUG_INIT_JOB(p_caplist) \
debug_dump ("--- CAP_CONTEXT_LIST INITJOB ---\n\n" \
        "output     = -----\n" \
        "paper_src  = %s\n" \
        "paper      = %s\n" \
        "format     = %s\n" \
        "resol      = %s\n" \
        "high_speed = %s\n" \
        "media_type = %s\n" \
        "margin     = (%s, %s)\n" \
        "paper_size = (%s, %s)\n" \
        "paper_area = (%s, %s)\n" \
        "mw_type    = %s\n" \
        "inkset     = %s\n" \
        "auto_cut   = %s\n\n" \
        "--------------------------\n\n" \
        ,GetCapValue (p_caplist, P_PAPER_SOURCE) \
        ,GetCapValue (p_caplist, P_MEDIA_SIZE) \
        ,GetCapValue (p_caplist, P_COLOR_MODE) \
        ,GetCapValue (p_caplist, P_RESOLUTION) \
        ,GetCapValue (p_caplist, P_HIGH_SPEED) \
        ,GetCapValue (p_caplist, P_MEDIA_TYPE) \
        ,GetCapValue (p_caplist, P_MARGIN_X) \
        ,GetCapValue (p_caplist, P_MARGIN_Y) \
        ,GetCapValue (p_caplist, P_PAPER_SIZE_X) \
        ,GetCapValue (p_caplist, P_PAPER_SIZE_Y) \
        ,GetCapValue (p_caplist, P_PAPER_AREA_X) \
        ,GetCapValue (p_caplist, P_PAPER_AREA_Y) \
        ,GetCapValue (p_caplist, P_MICRO_WEAVE) \
        ,GetCapValue (p_caplist, P_INKSET) \
        ,GetCapValue (p_caplist, P_AUTO_CUT) \
        )

#define DEBUG_INIT_PAGE(p_caplist) \
debug_dump ("--- CAP_CONTEXT_LIST INITPAGE ---\n\n" \
        "halftone_type = %s\n" \
        "brightness    = %s\n" \
        "contrast      = %s\n" \
        "saturation    = %s\n" \
        "c_strength    = %s\n" \
        "m_strength    = %s\n" \
        "y_strength    = %s\n\n" \
        "--------------------------\n\n" \
        ,GetCapValue (p_caplist, P_HALF_TONE) \
        ,GetCapValue (p_caplist, P_BRIGHTNESS) \
        ,GetCapValue (p_caplist, P_CONTRAST) \
        ,GetCapValue (p_caplist, P_SATURATION) \
        ,GetCapValue (p_caplist, P_STRENGTH_CYAN) \
        ,GetCapValue (p_caplist, P_STRENGTH_MAGENTA) \
        ,GetCapValue (p_caplist, P_STRENGTH_YELLOW) \
        )

#define DEBUG_BAND_OUT(band_str) \
debug_dump ("--- BAND OUT ---\n\n" \
        "width_pixel = %d\n" \
        "line_number = %d\n" \
        "width_bytes = %d\n" \
        "byte_data   = -----\n\n" \
        "--------------------------\n\n" \
        ,band_str.clip.width \
        ,band_str.clip.height \
        ,band_str.rows->size \
        )

    void debug_init ();
    void debug_dump (const char *, ...);
    void debug_end ();

#ifdef __cplusplus
}
#endif /* __cplusplus */

//#endif /* DEBUG */

#endif /* __DEBUG_H__ */
