/*
 * Photo Image Print System
 * Copyright (C) 2000-2005 EPSON AVASYS Corporation.
 * Copyright (C) Seiko Epson Corporation 2000-2008.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON AVASYS Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON AVASYS Public License and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON AVASYS Public License.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif
 
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <assert.h>
#include "setup.h"
#include "ekpdtool.h"
#include "support.h"


GtkWidget* mainwindow;
static char** model_list = NULL;
static char** alias_list = NULL;
static char** device_list = NULL;
static char* def_prt_name = NULL;
static GList* ConvertToGList(char**);
static GList* GetDevicePath(int);
static int GetIndexName(char**,char*);
static char* GetValue (char *,int);

//create main window reference
int create_main_window(GtkWidget* window)
{
    GList* tmp = NULL ;
    GtkWidget* widget = NULL;
    GList *optionDevice_items = NULL;

    mainwindow = window;
    gtk_widget_show (mainwindow);


    if (access (PIPS_EKPD_RC_PATH, F_OK | R_OK) != 0)
    {
	    fprintf (stderr, "%s: %s\n", N_("PIPS Warning"), N_("Printer not install."));
	    return 1;
    }

    model_list = GetModelListName (PNG_TYPE);
    alias_list = GetSubListName ("aliasname");
    device_list = GetSubListName ("devicepath");
    def_prt_name = GetDefaultPrinter (PNG_TYPE);
    
    if (*device_list == NULL) {
	    /* error */
	    fprintf (stderr, "%s: %s\n", N_("PIPS Error"), N_("Printer not install."));
	    return 1;
    }
    
    /* Model list */
    if (strlen (*device_list) > 0)
    {
            widget = lookup_widget (mainwindow, "optionDevice");
            optionDevice_items = g_list_append (optionDevice_items, (gpointer) _("USB"));
            optionDevice_items = g_list_append (optionDevice_items, (gpointer) _("Parallel Port"));
	    
            gtk_combo_set_popdown_strings (GTK_COMBO (widget), optionDevice_items);
            g_list_free (optionDevice_items);
            gtk_widget_show(widget);
    }
    
    if (strlen (*model_list) > 0)
    {
            tmp = ConvertToGList (model_list);
            widget = lookup_widget (mainwindow, "optionModel");
            gtk_combo_set_popdown_strings (GTK_COMBO (widget), tmp);
    }
    
    if (def_prt_name > 0)
    {
            if (GetIndexName (model_list, def_prt_name) > -1)
            {
		    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (widget)->entry), def_prt_name);
		    gtk_widget_show(widget);
            }
            else
		    fprintf (stderr, "%s: %s\n", N_("PIPS Warning"), N_("Default printer not found."));
    }
    
    return 0;
};

static
GList* ConvertToGList(char** char_list)
{
    GList* tmp = NULL;
    while(*char_list != NULL)
    {
        tmp = g_list_append (tmp, (gpointer) _(*char_list));
        char_list ++;
    }
    return tmp;
}

void model_selection_changed(guint index)
{
    char *port_value = NULL, *device_value = NULL;
    int port_type = 1;
    GtkWidget* widget = lookup_widget( mainwindow,"entryAliasName");
    GtkWidget* checkbutton1 = lookup_widget (mainwindow,"checkbutton1");
    gtk_entry_set_text(GTK_ENTRY(widget),alias_list[index]);

    if ((!def_prt_name) || (index != GetIndexName(model_list,def_prt_name)))
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), FALSE);
    else
        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (checkbutton1), TRUE);
    gtk_widget_show(widget);

    /* Device type*/
    if (!strncmp (device_list[index], "/dev/usb/lp", 11))
    {
	device_value = _("USB");
        port_value = GetValue (device_list[index], 3);
        port_type = 0;
    }
    else if (!strncmp (device_list[index], "/dev/lp", 7))
    {
	device_value = _("Parallel Port");
        port_value = GetValue (device_list[index], 2);
        port_type = 1;
    }
    else
    {
	assert (0);
    }
    /* else if (!strncmp (device_list[index], "/dev/usb/lp", 10)) */

    if (device_list)
    {
        widget = lookup_widget ( mainwindow, "optionDevice" );
        gtk_entry_set_text(GTK_ENTRY( GTK_COMBO (widget)->entry), device_value);

        /* Port list */
        port_selection_changed (port_type);
        widget = lookup_widget ( mainwindow, "optionPort" );
        gtk_entry_set_text(GTK_ENTRY( GTK_COMBO (widget)->entry), port_value);
    }
}

void port_selection_changed(guint index)
{
    if (device_list)
    {
	GList *entry = NULL;
        GtkWidget* optionPort;
	GtkWidget* labelPort;
	GtkWidget* buttonOk;

	entry = GetDevicePath(index);
	optionPort = lookup_widget(mainwindow,"optionPort");
	labelPort = lookup_widget(mainwindow,"labelPort");
	buttonOk = lookup_widget(mainwindow,"buttonOk");
	
	if (entry == NULL) {
		gtk_widget_set_sensitive(optionPort, FALSE);
		gtk_widget_set_sensitive(labelPort, FALSE);
		gtk_widget_set_sensitive(buttonOk, FALSE);
	} else {
		gtk_widget_set_sensitive(optionPort, TRUE);
		gtk_widget_set_sensitive(labelPort, TRUE);
		gtk_widget_set_sensitive(buttonOk, TRUE);
		gtk_combo_set_popdown_strings(GTK_COMBO(optionPort),GetDevicePath(index));
	}
    }

    return;
}

static GList* GetDevicePath(int device_type)
{
    int i, num;
    char* device[17];

    if (device_type == 0) /* usb device */
        num = 16;
    else if (device_type == 1) /* parallel device */
        num = 5;
    else
        num = 0;

    for (i = 0; i < num; i++)
    {
	    device[i] = (char*) malloc(5);
	    sprintf (device[i], "%s%d", "lp", i);
	    if (device_type == 1) {
		    /* Check file when selected parallel port. */
		    char *path = NULL;
		    path = (char*)malloc(sizeof("/dev/") + sizeof(device[i]) + 1);
		    if (path != NULL) {
			    sprintf(path, "/dev/%s", device[i]);
			    if (access(path, R_OK | W_OK)) {
				    free (device[i]);
				    break;
			    }
			    free (path);
		    }
	    }
    }
    
    device[i] = NULL;
    
    if (i == 0) {
	    return NULL;
    }
    return (GList*)ConvertToGList(device);
};

static int GetIndexName(char** data_list, char* string)
{
    int count = 0;

    while(*data_list!=NULL)
    {
        if(!strcmp(string,*data_list))
            return count;

        count += 1;
        data_list++;
    }
    return -1;
}

static char*
GetValue (char *list, int pos)
{
    int i = 1;
    char *strTemp;
    char *value = NULL, *list_temp;

    list_temp = strdup (list);
    strTemp = strtok (list_temp, "/");
    while (i < pos)
    {
        strTemp = strtok (NULL, "/");
        i ++;
    }

    if (strTemp)
        value = strdup (strTemp);
    else
        value = list;

    return value;
}

//test setting
int ekpdtool_test_setting (GtkWidget *mainwindow)
{
    char cmd_buf[MAX_SIZE], device_path[32];
    char *printer = NULL, *device = NULL, *port = NULL;
    GtkWidget *widget;

    widget = lookup_widget( mainwindow,"entryAliasName");
    printer = (char*)gtk_entry_get_text (GTK_ENTRY (widget));

    widget = lookup_widget( mainwindow,"optionDevice");
    device = (char*)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (widget)->entry));

    widget = lookup_widget( mainwindow,"optionPort");
    port = (char*)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (widget)->entry));

    if (!strcmp (device, _("USB")))
        sprintf (device_path, "/dev/%s/%s", device, port);
    else if (!strcmp (device, _("Parallel Port")))
        sprintf (device_path, "/dev/%s", port);
    else
	assert(0);
    //else if (!strcmp (device, "ieee"))
    sprintf (cmd_buf, "echo \"Printer name: %s\nDevice Path: %s\n\" > %s", printer, device_path, device_path);
    system (cmd_buf);
    sprintf (cmd_buf, "cat %s > %s", PIPS_GUI_DIR"/pips_testpage.prn", device_path);
    system (cmd_buf); //fprintf (stderr, "%s", cmd_buf);

    return 0;
};

// write setting
int ekpdtool_write_setting (GtkWidget *mainwindow)
{
    char cmd_buf[MAX_SIZE], setup_buf[MAX_SIZE], device_path[32];
    char *printer = NULL, *device = NULL, *port = NULL, *model = NULL;
    BOOL def_prt = FALSE;
    int index = 0;

    GtkWidget *widget;

    widget = lookup_widget( mainwindow,"optionModel");
    model = (char*)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (widget)->entry));

    widget = lookup_widget( mainwindow,"entryAliasName");
    printer = (char*)gtk_entry_get_text (GTK_ENTRY (widget));

    widget = lookup_widget( mainwindow,"optionDevice");
    device = (char*)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (widget)->entry));

    widget = lookup_widget( mainwindow,"optionPort");
    port = (char*)gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (widget)->entry));
    //else if (!strcmp (device, "ieee"))

    if ((strlen(model) == 0) || (strlen (printer) == 0) || (strlen (device) == 0) || (strlen (port) == 0))
        return 1;

    widget = lookup_widget (mainwindow,"checkbutton1");
    def_prt = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));

    if (!strcmp (device, _("USB")))
        sprintf (device_path, "/dev/usb/%s", port);
    else if (!strcmp (device, _("Parallel Port")))
        sprintf (device_path, "/dev/%s", port);
    else
	assert (0);		/* Error */

    //else if (!strcmp (device, "ieee"))

    index = GetIndexName (model_list, model);

    memset (setup_buf, '\0', MAX_SIZE);

    if (strcmp (device_path, device_list[index]))
        sprintf (setup_buf, "%s -d %s", setup_buf, device_path);

    if (((def_prt) && (def_prt_name) && (strcmp (def_prt_name, model))) ||
        (def_prt && !def_prt_name))
        sprintf (setup_buf, "%s -a", setup_buf);

    if (setup_buf[0])
    {
        sprintf (cmd_buf, PIPS_CORE_DIR"/setup -p %s %s", model, setup_buf);
        system (cmd_buf);
    }
    else
        fprintf (stderr, "%s\n", _("Nothing to be changed."));

    return 0;
};
