/*
 * Photo Image Print System
 * Copyright (C) Seiko Epson Corporation 2008.
 *
 * This file is part of the `espmntg' program.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_wndMain (void)
{
  GtkWidget *wndMain;
  GdkPixbuf *wndMain_icon_pixbuf;
  GtkWidget *scrolledwindow1;
  GtkWidget *ivwMain;

  wndMain = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndMain), _("Epson Printer Utility"));
  gtk_window_set_default_size (GTK_WINDOW (wndMain), 420, 140);
  wndMain_icon_pixbuf = create_pixbuf ("Mainte.ico");
  if (wndMain_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndMain), wndMain_icon_pixbuf);
      gdk_pixbuf_unref (wndMain_icon_pixbuf);
    }

  scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindow1);
  gtk_container_add (GTK_CONTAINER (wndMain), scrolledwindow1);
  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
  gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow1), GTK_SHADOW_IN);

  ivwMain = gtk_icon_view_new ();
  gtk_widget_show (ivwMain);
  gtk_container_add (GTK_CONTAINER (scrolledwindow1), ivwMain);

  g_signal_connect ((gpointer) wndMain, "destroy",
                    G_CALLBACK (on_wndMain_destroy),
                    NULL);
  g_signal_connect ((gpointer) ivwMain, "item_activated",
                    G_CALLBACK (on_ivwMain_item_activated),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndMain, wndMain, "wndMain");
  GLADE_HOOKUP_OBJECT (wndMain, scrolledwindow1, "scrolledwindow1");
  GLADE_HOOKUP_OBJECT (wndMain, ivwMain, "ivwMain");

  return wndMain;
}

GtkWidget*
create_wndNozzle1 (void)
{
  GtkWidget *wndNozzle1;
  GdkPixbuf *wndNozzle1_icon_pixbuf;
  GtkWidget *hbox2;
  GtkWidget *image7;
  GtkWidget *vbox1;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox2;
  GtkWidget *btnExec;
  GtkWidget *btnFin;

  wndNozzle1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndNozzle1), _("Nozzle Check"));
  gtk_window_set_position (GTK_WINDOW (wndNozzle1), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndNozzle1), TRUE);
  wndNozzle1_icon_pixbuf = create_pixbuf ("Nozzle.ico");
  if (wndNozzle1_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndNozzle1), wndNozzle1_icon_pixbuf);
      gdk_pixbuf_unref (wndNozzle1_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndNozzle1), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndNozzle1), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox2 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (wndNozzle1), hbox2);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2), 8);

  image7 = create_pixmap (wndNozzle1, "viNozzle.xpm");
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox2), image7, TRUE, TRUE, 4);

  vbox1 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox1);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox1, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox1), lblDesc, FALSE, FALSE, 4);

  hbuttonbox2 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox2);
  gtk_box_pack_start (GTK_BOX (vbox1), hbuttonbox2, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox2), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox2), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Print"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Finish"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox2), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndNozzle1));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndNozzle1, wndNozzle1, "wndNozzle1");
  GLADE_HOOKUP_OBJECT (wndNozzle1, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (wndNozzle1, image7, "image7");
  GLADE_HOOKUP_OBJECT (wndNozzle1, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (wndNozzle1, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndNozzle1, hbuttonbox2, "hbuttonbox2");
  GLADE_HOOKUP_OBJECT (wndNozzle1, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndNozzle1, btnFin, "btnFin");

  return wndNozzle1;
}

GtkWidget*
create_wndClean1 (void)
{
  GtkWidget *wndClean1;
  GdkPixbuf *wndClean1_icon_pixbuf;
  GtkWidget *hbox2;
  GtkWidget *image7;
  GtkWidget *vbox5;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox3;
  GtkWidget *btnFin;
  GtkWidget *btnExec;

  wndClean1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndClean1), _("Head Cleaning"));
  gtk_window_set_position (GTK_WINDOW (wndClean1), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndClean1), TRUE);
  wndClean1_icon_pixbuf = create_pixbuf ("Clean.ico");
  if (wndClean1_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndClean1), wndClean1_icon_pixbuf);
      gdk_pixbuf_unref (wndClean1_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndClean1), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndClean1), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox2 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (wndClean1), hbox2);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2), 8);

  image7 = create_pixmap (wndClean1, "viClean.xpm");
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox2), image7, TRUE, TRUE, 4);

  vbox5 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox5);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox5, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox5), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox5), lblDesc, FALSE, FALSE, 4);

  hbuttonbox3 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox3);
  gtk_box_pack_start (GTK_BOX (vbox5), hbuttonbox3, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox3), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox3), 4);

  btnFin = gtk_button_new_with_mnemonic (_("Cancel"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  btnExec = gtk_button_new_with_mnemonic (_("Start"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox3), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndClean1));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndClean1, wndClean1, "wndClean1");
  GLADE_HOOKUP_OBJECT (wndClean1, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (wndClean1, image7, "image7");
  GLADE_HOOKUP_OBJECT (wndClean1, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (wndClean1, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndClean1, hbuttonbox3, "hbuttonbox3");
  GLADE_HOOKUP_OBJECT (wndClean1, btnFin, "btnFin");
  GLADE_HOOKUP_OBJECT (wndClean1, btnExec, "btnExec");

  return wndClean1;
}

GtkWidget*
create_wndNozzle2 (void)
{
  GtkWidget *wndNozzle2;
  GdkPixbuf *wndNozzle2_icon_pixbuf;
  GtkWidget *vbox3;
  GtkWidget *image9;
  GtkWidget *label10;
  GtkWidget *image10;
  GtkWidget *label11;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox4;
  GtkWidget *btnExec;
  GtkWidget *btnFin;

  wndNozzle2 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndNozzle2), _("Nozzle Check"));
  gtk_window_set_position (GTK_WINDOW (wndNozzle2), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndNozzle2), TRUE);
  wndNozzle2_icon_pixbuf = create_pixbuf ("Nozzle.ico");
  if (wndNozzle2_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndNozzle2), wndNozzle2_icon_pixbuf);
      gdk_pixbuf_unref (wndNozzle2_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndNozzle2), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndNozzle2), GDK_WINDOW_TYPE_HINT_DIALOG);

  vbox3 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox3);
  gtk_container_add (GTK_CONTAINER (wndNozzle2), vbox3);
  gtk_container_set_border_width (GTK_CONTAINER (vbox3), 8);

  image9 = create_pixmap (wndNozzle2, "npg.xpm");
  gtk_widget_show (image9);
  gtk_box_pack_start (GTK_BOX (vbox3), image9, TRUE, TRUE, 4);

  label10 = gtk_label_new (_("Good"));
  gtk_widget_show (label10);
  gtk_box_pack_start (GTK_BOX (vbox3), label10, FALSE, FALSE, 0);

  image10 = create_pixmap (wndNozzle2, "npb.xpm");
  gtk_widget_show (image10);
  gtk_box_pack_start (GTK_BOX (vbox3), image10, TRUE, TRUE, 0);

  label11 = gtk_label_new (_("Cleaning needed"));
  gtk_widget_show (label11);
  gtk_box_pack_start (GTK_BOX (vbox3), label11, FALSE, FALSE, 0);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox3), lblDesc, FALSE, FALSE, 4);

  hbuttonbox4 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox4);
  gtk_box_pack_start (GTK_BOX (vbox3), hbuttonbox4, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox4), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox4), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Clean"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Finish"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox4), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndNozzle2));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndNozzle2, wndNozzle2, "wndNozzle2");
  GLADE_HOOKUP_OBJECT (wndNozzle2, vbox3, "vbox3");
  GLADE_HOOKUP_OBJECT (wndNozzle2, image9, "image9");
  GLADE_HOOKUP_OBJECT (wndNozzle2, label10, "label10");
  GLADE_HOOKUP_OBJECT (wndNozzle2, image10, "image10");
  GLADE_HOOKUP_OBJECT (wndNozzle2, label11, "label11");
  GLADE_HOOKUP_OBJECT (wndNozzle2, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndNozzle2, hbuttonbox4, "hbuttonbox4");
  GLADE_HOOKUP_OBJECT (wndNozzle2, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndNozzle2, btnFin, "btnFin");

  return wndNozzle2;
}

GtkWidget*
create_wndClean2 (void)
{
  GtkWidget *wndClean2;
  GdkPixbuf *wndClean2_icon_pixbuf;
  GtkWidget *hbox2;
  GtkWidget *image7;
  GtkWidget *vbox4;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox5;
  GtkWidget *btnExec;
  GtkWidget *btnFin;

  wndClean2 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndClean2), _("Head Cleaning"));
  gtk_window_set_position (GTK_WINDOW (wndClean2), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndClean2), TRUE);
  wndClean2_icon_pixbuf = create_pixbuf ("Clean.ico");
  if (wndClean2_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndClean2), wndClean2_icon_pixbuf);
      gdk_pixbuf_unref (wndClean2_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndClean2), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndClean2), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox2 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox2);
  gtk_container_add (GTK_CONTAINER (wndClean2), hbox2);
  gtk_container_set_border_width (GTK_CONTAINER (hbox2), 8);

  image7 = create_pixmap (wndClean2, "viClean.xpm");
  gtk_widget_show (image7);
  gtk_box_pack_start (GTK_BOX (hbox2), image7, TRUE, TRUE, 4);

  vbox4 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox4);
  gtk_box_pack_start (GTK_BOX (hbox2), vbox4, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox4), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox4), lblDesc, FALSE, FALSE, 4);

  hbuttonbox5 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox5);
  gtk_box_pack_start (GTK_BOX (vbox4), hbuttonbox5, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox5), GTK_BUTTONBOX_END);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox5), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Print Nozzle Check Pattern"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Finish"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox5), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndClean2));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndClean2, wndClean2, "wndClean2");
  GLADE_HOOKUP_OBJECT (wndClean2, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (wndClean2, image7, "image7");
  GLADE_HOOKUP_OBJECT (wndClean2, vbox4, "vbox4");
  GLADE_HOOKUP_OBJECT (wndClean2, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndClean2, hbuttonbox5, "hbuttonbox5");
  GLADE_HOOKUP_OBJECT (wndClean2, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndClean2, btnFin, "btnFin");

  return wndClean2;
}

GtkWidget*
create_wndGap1 (void)
{
  GtkWidget *wndGap1;
  GdkPixbuf *wndGap1_icon_pixbuf;
  GtkWidget *hbox1;
  GtkWidget *image12;
  GtkWidget *vbox5;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox6;
  GtkWidget *btnExec;
  GtkWidget *btnFin;

  wndGap1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndGap1), _("Print Head Alignment"));
  gtk_window_set_position (GTK_WINDOW (wndGap1), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndGap1), TRUE);
  wndGap1_icon_pixbuf = create_pixbuf ("Gap.ico");
  if (wndGap1_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndGap1), wndGap1_icon_pixbuf);
      gdk_pixbuf_unref (wndGap1_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndGap1), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndGap1), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox1 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox1);
  gtk_container_add (GTK_CONTAINER (wndGap1), hbox1);
  gtk_container_set_border_width (GTK_CONTAINER (hbox1), 8);

  image12 = create_pixmap (wndGap1, "viGap.xpm");
  gtk_widget_show (image12);
  gtk_box_pack_start (GTK_BOX (hbox1), image12, TRUE, TRUE, 4);

  vbox5 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox5);
  gtk_box_pack_start (GTK_BOX (hbox1), vbox5, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox5), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox5), lblDesc, FALSE, FALSE, 4);

  hbuttonbox6 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox6);
  gtk_box_pack_start (GTK_BOX (vbox5), hbuttonbox6, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox6), GTK_BUTTONBOX_SPREAD);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox6), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Next>"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Cancel"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox6), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndGap1));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndGap1, wndGap1, "wndGap1");
  GLADE_HOOKUP_OBJECT (wndGap1, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (wndGap1, image12, "image12");
  GLADE_HOOKUP_OBJECT (wndGap1, vbox5, "vbox5");
  GLADE_HOOKUP_OBJECT (wndGap1, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndGap1, hbuttonbox6, "hbuttonbox6");
  GLADE_HOOKUP_OBJECT (wndGap1, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndGap1, btnFin, "btnFin");

  return wndGap1;
}

GtkWidget*
create_wndGap2 (void)
{
  GtkWidget *wndGap2;
  GdkPixbuf *wndGap2_icon_pixbuf;
  GtkWidget *hbox3;
  GtkWidget *image13;
  GtkWidget *vbox6;
  GtkWidget *lblDesc;
  GtkWidget *hbuttonbox7;
  GtkWidget *btnExec;
  GtkWidget *btnFin;
  GtkWidget *btnExec2;

  wndGap2 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndGap2), _("Print Head Alignment"));
  gtk_window_set_position (GTK_WINDOW (wndGap2), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndGap2), TRUE);
  wndGap2_icon_pixbuf = create_pixbuf ("Gap.ico");
  if (wndGap2_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndGap2), wndGap2_icon_pixbuf);
      gdk_pixbuf_unref (wndGap2_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndGap2), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndGap2), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox3 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox3);
  gtk_container_add (GTK_CONTAINER (wndGap2), hbox3);
  gtk_container_set_border_width (GTK_CONTAINER (hbox3), 8);

  image13 = create_pixmap (wndGap2, "viGap.xpm");
  gtk_widget_show (image13);
  gtk_box_pack_start (GTK_BOX (hbox3), image13, TRUE, TRUE, 4);

  vbox6 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox6);
  gtk_box_pack_start (GTK_BOX (hbox3), vbox6, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox6), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox6), lblDesc, FALSE, FALSE, 4);

  hbuttonbox7 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox7);
  gtk_box_pack_start (GTK_BOX (vbox6), hbuttonbox7, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox7), GTK_BUTTONBOX_SPREAD);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox7), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Print"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Cancel"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  btnExec2 = gtk_button_new_with_mnemonic (_("Skip >>"));
  gtk_widget_show (btnExec2);
  gtk_container_add (GTK_CONTAINER (hbuttonbox7), btnExec2);
  GTK_WIDGET_SET_FLAGS (btnExec2, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndGap2));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndGap2, wndGap2, "wndGap2");
  GLADE_HOOKUP_OBJECT (wndGap2, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (wndGap2, image13, "image13");
  GLADE_HOOKUP_OBJECT (wndGap2, vbox6, "vbox6");
  GLADE_HOOKUP_OBJECT (wndGap2, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndGap2, hbuttonbox7, "hbuttonbox7");
  GLADE_HOOKUP_OBJECT (wndGap2, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndGap2, btnFin, "btnFin");
  GLADE_HOOKUP_OBJECT (wndGap2, btnExec2, "btnExec2");

  return wndGap2;
}

GtkWidget*
create_wndGap3 (void)
{
  GtkWidget *wndGap3;
  GdkPixbuf *wndGap3_icon_pixbuf;
  GtkWidget *hbox4;
  GtkWidget *image14;
  GtkWidget *vbox7;
  GtkWidget *lblDesc;
  GtkWidget *vboxGapPrm;
  GtkWidget *hbuttonbox8;
  GtkWidget *btnExec;
  GtkWidget *btnFin;
  GtkWidget *btnExec2;

  wndGap3 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (wndGap3), _("Print Head Alignment"));
  gtk_window_set_position (GTK_WINDOW (wndGap3), GTK_WIN_POS_CENTER);
  gtk_window_set_modal (GTK_WINDOW (wndGap3), TRUE);
  wndGap3_icon_pixbuf = create_pixbuf ("Gap.ico");
  if (wndGap3_icon_pixbuf)
    {
      gtk_window_set_icon (GTK_WINDOW (wndGap3), wndGap3_icon_pixbuf);
      gdk_pixbuf_unref (wndGap3_icon_pixbuf);
    }
  gtk_window_set_skip_taskbar_hint (GTK_WINDOW (wndGap3), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (wndGap3), GDK_WINDOW_TYPE_HINT_DIALOG);

  hbox4 = gtk_hbox_new (FALSE, 8);
  gtk_widget_show (hbox4);
  gtk_container_add (GTK_CONTAINER (wndGap3), hbox4);
  gtk_container_set_border_width (GTK_CONTAINER (hbox4), 8);

  image14 = create_pixmap (wndGap3, "viGap.xpm");
  gtk_widget_show (image14);
  gtk_box_pack_start (GTK_BOX (hbox4), image14, TRUE, TRUE, 4);

  vbox7 = gtk_vbox_new (FALSE, 8);
  gtk_widget_show (vbox7);
  gtk_box_pack_start (GTK_BOX (hbox4), vbox7, TRUE, TRUE, 4);
  gtk_container_set_border_width (GTK_CONTAINER (vbox7), 8);

  lblDesc = gtk_label_new ("");
  gtk_widget_show (lblDesc);
  gtk_box_pack_start (GTK_BOX (vbox7), lblDesc, FALSE, FALSE, 4);

  vboxGapPrm = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vboxGapPrm);
  gtk_box_pack_start (GTK_BOX (vbox7), vboxGapPrm, FALSE, FALSE, 4);

  hbuttonbox8 = gtk_hbutton_box_new ();
  gtk_widget_show (hbuttonbox8);
  gtk_box_pack_start (GTK_BOX (vbox7), hbuttonbox8, TRUE, TRUE, 4);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (hbuttonbox8), GTK_BUTTONBOX_SPREAD);
  gtk_box_set_spacing (GTK_BOX (hbuttonbox8), 4);

  btnExec = gtk_button_new_with_mnemonic (_("Realignment"));
  gtk_widget_show (btnExec);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), btnExec);
  GTK_WIDGET_SET_FLAGS (btnExec, GTK_CAN_DEFAULT);

  btnFin = gtk_button_new_with_mnemonic (_("Cancel"));
  gtk_widget_show (btnFin);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), btnFin);
  GTK_WIDGET_SET_FLAGS (btnFin, GTK_CAN_DEFAULT);

  btnExec2 = gtk_button_new_with_mnemonic (_("Finish"));
  gtk_widget_show (btnExec2);
  gtk_container_add (GTK_CONTAINER (hbuttonbox8), btnExec2);
  GTK_WIDGET_SET_FLAGS (btnExec2, GTK_CAN_DEFAULT);

  g_signal_connect_swapped ((gpointer) btnFin, "clicked",
                            G_CALLBACK (gtk_widget_destroy),
                            GTK_OBJECT (wndGap3));

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (wndGap3, wndGap3, "wndGap3");
  GLADE_HOOKUP_OBJECT (wndGap3, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (wndGap3, image14, "image14");
  GLADE_HOOKUP_OBJECT (wndGap3, vbox7, "vbox7");
  GLADE_HOOKUP_OBJECT (wndGap3, lblDesc, "lblDesc");
  GLADE_HOOKUP_OBJECT (wndGap3, vboxGapPrm, "vboxGapPrm");
  GLADE_HOOKUP_OBJECT (wndGap3, hbuttonbox8, "hbuttonbox8");
  GLADE_HOOKUP_OBJECT (wndGap3, btnExec, "btnExec");
  GLADE_HOOKUP_OBJECT (wndGap3, btnFin, "btnFin");
  GLADE_HOOKUP_OBJECT (wndGap3, btnExec2, "btnExec2");

  return wndGap3;
}

